@@ -20,7 +20,6 @@ from .literals import (
     ArtifactPackagingType,
     ArtifactsTypeType,
     AuthTypeType,
-    BatchReportModeTypeType,
     BucketOwnerAccessType,
     BuildBatchPhaseTypeType,
     BuildPhaseTypeType,
@@ -1281,7 +1280,6 @@ ProjectBuildBatchConfigTypeDef = TypedDict(
         "combineArtifacts": bool,
         "restrictions": "BatchRestrictionsTypeDef",
         "timeoutInMins": int,
-        "batchReportMode": BatchReportModeTypeType,
     },
     total=False,
 )
